embassy-stm32

Crates

git

Versions

stm32u585oi

Flavors

FilterInterrupt

Trait FilterInterrupt 

pub trait FilterInterrupt: Filter {
    type Interrupt: Interrupt;
}
A Filter whose interrupt is routed on the compiled chip.

Not every chip’s MDF1 instance exposes all six filters (e.g. STM32U535/U545 only have FLT0/FLT1), so this is only implemented for filters that actually have an interrupt.

Required Associated Types

type Interrupt: Interrupt

Interrupt for this filter.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors